redvox.api1000.wrapped_redvox_packet.sensors API documentation

# Module `redvox.api1000.wrapped_redvox_packet.sensors`

## Sub-modules

`redvox.api1000.wrapped_redvox_packet.sensors.audio`

  This module encapsulates audio sensor metadata and data.

`redvox.api1000.wrapped_redvox_packet.sensors.derived`
`redvox.api1000.wrapped_redvox_packet.sensors.image`

  This module provides functionality for working with API M image sensors.

`redvox.api1000.wrapped_redvox_packet.sensors.location`

  This module provides tools for working with RedVox API M location data and metadata.

`redvox.api1000.wrapped_redvox_packet.sensors.sensors`

  This module encapsulates available sensor types.

`redvox.api1000.wrapped_redvox_packet.sensors.single`

  This module provides functionality for working with single channel API M sensors.

`redvox.api1000.wrapped_redvox_packet.sensors.xyz`

  This module contains functionality for working with XYZ channeled API M sensors.